@@ -1,5 +1,5 @@
 """Tests for the templatetags of the ``project-kairos`` project."""
-from mock import Mock
+from mock import Mock, patch
 
 from django.template import Context, Template
 from django.test import RequestFactory, TestCase
@@ -128,6 +128,22 @@ class NavactiveTestCase(TestCase):
             "When the given string is a url name, it should return"
             " '', if it matches the path, but returned %s" % result))
 
+    @patch('django_libs.templatetags.libs_tags.resolve')
+    def test_use_resolver_true(self, mock_resolve):
+        req = RequestFactory().get('/index/test/')
+        result = navactive(req, '/index/test/')
+        self.assertTrue(mock_resolve.called, msg=(
+            'When calling the tag normally, we will try to resolve the given'
+            ' url.'))
+
+    @patch('django_libs.templatetags.libs_tags.resolve')
+    def test_use_resolver_false(self, mock_resolve):
+        req = RequestFactory().get('/index/test/')
+        result = navactive(req, '/index/test/', use_resolver=False)
+        self.assertFalse(mock_resolve.called, msg=(
+            'When calling the tag with use_resolve=False the resolver should'
+            ' not be called at all'))
+
 
 class GetRangeTestCase(TestCase):
     """Tests for the ``get_range`` filter."""
@@ -138,6 +154,11 @@ class GetRangeTestCase(TestCase):
         self.assertEqual(result, range(5), msg=(
             "Filter should behave exactly like Python's range function"))
 
+    def test_filter_with_max_num(self):
+        result = get_range(3, 5)
+        self.assertEqual(result, range(2), msg=(
+            'Filter should return the difference between value and max_num'))
+
 
 class RenderAnalyticsCodeTestCase(TestCase):
     """Tests for the ``render_analytics_code`` templatetag."""
